@@ -38,13 +38,14 @@ setClass("DirectedPair", contains = "MatchTable",
 #'  represents random digits.
 #'@param title A character representing the title of the XML file associated
 #'  with the task. By default, it takes the value of the identifier.
-#'@param content A list of character content to form the text of the question,
-#'  which can include HTML tags.
+#'@param content A character string or a list of character strings to form the
+#'   text of the question, which may include HTML tags.
 #'@param prompt An optional character representing a simple question text,
 #'  consisting of one paragraph. This can supplement or replace content in the
 #'  task. Default is "".
 #'@param points A numeric value, optional, representing the number of points for
-#'  the entire task. Default is 1.
+#'  the entire task. If not provided, the default is calculated as 0.5 points
+#'  per pair.
 #'@param rows A character vector specifying answer options as the first elements
 #'  in couples.
 #'@param rows_identifiers A character vector, optional, specifies identifiers of
@@ -82,7 +83,7 @@ setClass("DirectedPair", contains = "MatchTable",
 #'  be accessible to the candidate during the test/exam.
 #'@return An object of class [DirectedPair]
 #' @examples
-#' dp_min <- directedPair(content = list("<p>\"Directed pairs\" task</p>"),
+#' dp_min <- directedPair(content = "<p>\"Directed pairs\" task</p>",
 #'                        rows = c("alfa", "beta", "gamma"),
 #'                        rows_identifiers = c("a", "b", "g"),
 #'                        cols = c("A", "B", "G;"),
@@ -91,7 +92,7 @@ setClass("DirectedPair", contains = "MatchTable",
 #'
 #' dp <- directedPair(identifier = "id_task_1234",
 #'                    title = "Directed Pair Task",
-#'                    content = list("<p>\"Directed pairs\" task</p>"),
+#'                    content = "<p>\"Directed pairs\" task</p>",
 #'                    prompt = "Plain text, can be used instead of the content",
 #'                    rows = c("alfa", "beta", "gamma"),
 #'                    rows_identifiers = c("a", "b", "g"),
@@ -122,14 +123,17 @@ directedPair <- function(identifier = generate_id(),
                          calculator = NA_character_,
                          files = NA_character_) {
     params <- as.list(environment())
+    if (is.character(params$content)) params$content <- list(params$content)
     params$Class <- "DirectedPair"
     obj <- do.call("new", params)
     return(obj)
 }
 
+
 #' @rdname createItemBody-methods
 #' @aliases createItemBody,DirectedPair
-setMethod("createItemBody",  "DirectedPair", function(object) {
-    if (object@orientation == "horizontal") ort <- "horizontal" else ort <- NULL
-    create_item_body_match_table(object, 1, 1, 0, ort)
+setMethod("createItemBody", signature(object = "DirectedPair"),
+          function(object) {
+              if (object@orientation == "horizontal") ort <- "horizontal" else ort <- NULL
+              create_item_body_match_table(object, 1, 1, 0, ort)
 })
