@@ -39,8 +39,8 @@ setClass("MultipleChoice", contains = "Choice")
 #'   identifiers for answers. By default, identifiers are generated
 #'   automatically according to the template "ChoiceD", where D is a letter
 #'   representing the alphabetical order of the answer in the list.
-#' @param content A list of character content to form the text of the question,
-#'   which can include HTML tags.
+#' @param content A character string or a list of character strings to form the
+#'   text of the question, which may include HTML tags.
 #' @param prompt An optional character representing a simple question text,
 #'   consisting of one paragraph. This can supplement or replace content in the
 #'   task. Default is "".
@@ -72,7 +72,7 @@ setClass("MultipleChoice", contains = "Choice")
 #'
 #'mc <- multipleChoice(identifier = "id_task_1234",
 #'                    title = "Multiple Choice Task",
-#'                    content = list("<p>Pick up the right options</p>"),
+#'                    content = "<p>Pick up the right options</p>",
 #'                    prompt = "Plain text, can be used instead of content",
 #'                    points = c(0, 0.5, 0.5),
 #'                    feedback = list(new("WrongFeedback",
@@ -98,6 +98,7 @@ multipleChoice <- function(identifier = generate_id(),
                          calculator = NA_character_,
                          files = NA_character_) {
     params <- as.list(environment())
+    if (is.character(params$content)) params$content <- list(params$content)
     params$Class <- "MultipleChoice"
     obj <- do.call("new", params)
     return(obj)
