@@ -164,9 +164,10 @@ make_variant_subsection <- function(file, n_variants, seed_number) {
 #'   candidate for the test in minutes. Default is 90 minutes.
 #' @param max_attempts An integer value, optional, indicating the maximum number
 #'   of attempts allowed for the candidate. Default is 1.
-#' @param academic_grading A boolean, optional; enables showing a grade to the
-#'   candidate at the end of the testing according to the 5-point academic grade
-#'   system as feedback. Default is `FALSE.`
+#' @param academic_grading A named numeric vector that defines the grade table shown to the candidate as feedback at the end of the test. The default is the German grading system:
+#' gt <- c("1.0" = 0.95, "1.3" = 0.9, "1.7" = 0.85, "2.0" = 0.8, "2.3" = 0.75, "2.7" = 0.7, "3.0" = 0.65, "3.3" = 0.6, "3.7" = 0.55, "4.0" = 0.5, "5.0" = 0)
+#' Each grade corresponds to a minimum percentage score required to achieve it.
+#' To hide the grading table at the end of the test, set this parameter to NA_real_.
 #' @param grade_label A character value, optional; a short message that shows
 #'   with a grade in the final feedback; for multilingual use, it can be a named
 #'   vector with two-letter ISO language codes as names (e.g., c(en="Grade",
@@ -208,11 +209,14 @@ make_variant_subsection <- function(file, n_variants, seed_number) {
 #' sc <- new("SingleChoice", prompt = "Question", choices = c("A", "B", "C"))
 #' es <- new("Essay", prompt = "Question")
 #' s <- section(c(sc, es), title = "Section with nonrandomized tasks")
-#' t <- test(s, title = "Example of the Exam", academic_grading = TRUE)
+#' t <- test(s, title = "Example of the Exam")
 #'
 #'@export
 test <- function(content, identifier = "test_identifier", title = "Test Title",
-                 time_limit = 90L, max_attempts = 1L, academic_grading = FALSE,
+                 time_limit = 90L, max_attempts = 1L,
+                 academic_grading = c("1.0" = 0.95, "1.3" = 0.9, "1.7" = 0.85, "2.0" = 0.8,
+                                      "2.3" = 0.75, "2.7" = 0.7, "3.0" = 0.65, "3.3" = 0.6,
+                                      "3.7" = 0.55, "4.0" = 0.5, "5.0" = 0),
                  grade_label = c(en="Grade", de="Note"),
                  table_label = c(en="Grade", de="Note"),
                  navigation_mode = "nonlinear", submission_mode = "individual",
@@ -256,9 +260,10 @@ test <- function(content, identifier = "test_identifier", title = "Test Title",
 #'   - 'simple'
 #'   - 'scientific'.
 #'   Default is `NULL`.
-#' @param academic_grading A boolean, optional; enables to show to candidate at
-#'   the end of the testing a grade according to 5-point academic grade system
-#'   as a feedback; Default is `FALSE`.
+#' @param academic_grading A named numeric vector that defines the grade table shown to the candidate as feedback at the end of the test. The default is the German grading system:
+#' gt <- c("1.0" = 0.95, "1.3" = 0.9, "1.7" = 0.85, "2.0" = 0.8, "2.3" = 0.75, "2.7" = 0.7, "3.0" = 0.65, "3.3" = 0.6, "3.7" = 0.55, "4.0" = 0.5, "5.0" = 0)
+#' Each grade corresponds to a minimum percentage score required to achieve it.
+#' To hide the grading table at the end of the test, set this parameter to NA_real_.
 #' @param grade_label A character value, optional; a short message that shows
 #'   with a grade in the final feedback; for multilingual use, it can be a named
 #'   vector with two-letter ISO language codes as names (e.g., c(en="Grade",
@@ -307,13 +312,15 @@ test <- function(content, identifier = "test_identifier", title = "Test Title",
 #' sc <- new("SingleChoice", prompt = "Question", choices = c("A", "B", "C"))
 #' es <- new("Essay", prompt = "Question")
 #' s <- section(c(sc, es), title = "Section with nonrandomized tasks")
-#' t <- test4opal(s, title = "Example of the Exam", academic_grading = TRUE,
+#' t <- test4opal(s, title = "Example of the Exam",
 #' show_test_time = FALSE)
 #' @export
 test4opal <- function(content, identifier = "test_identifier",
                       title = "Test Title", time_limit = 90L, max_attempts = 1L,
                       files = NULL, calculator = NULL,
-                      academic_grading = FALSE,
+                      academic_grading = c("1.0" = 0.95, "1.3" = 0.9, "1.7" = 0.85, "2.0" = 0.8,
+                                           "2.3" = 0.75, "2.7" = 0.7, "3.0" = 0.65, "3.3" = 0.6,
+                                           "3.7" = 0.55, "4.0" = 0.5, "5.0" = 0),
                       grade_label = c(en="Grade", de="Note"),
                       table_label = c(en="Grade", de="Note"),
                       navigation_mode = "nonlinear",
@@ -340,7 +347,7 @@ test4opal <- function(content, identifier = "test_identifier",
 }
 
 add_test_metadata <- function(object, params) {
-    mtdata <- new("QtiMetadata", contributor = list(qti_contributor()),
+    mtdata <- new("QtiMetadata", contributor = list(qtiContributor()),
                   description = params$description,
                   rights = params$rights, version = params$version)
 
@@ -348,10 +355,10 @@ add_test_metadata <- function(object, params) {
         mtdata@contributor <- params$contributor
     } else {
         contr <- unlist(lapply(object@section, getContributors))
-        contr_ar <- lapply(contr, function(x) list(x@contributor, x@role))
+        contr_ar <- lapply(contr, function(x) list(x@name, x@role))
         contr_unique <- contr[!duplicated(contr_ar)]
         if (length(contr_unique) != 0) {
-            msg <- paste(sapply(contr_unique, function(x) paste0(x@contributor, " (", x@role, ")")),
+            msg <- paste(sapply(contr_unique, function(x) paste0(x@name, " (", x@role, ")")),
                          collapse = ", ")
             msg <- paste0("Authors are found in exercises and added as",
                           " contributors: ", msg, ".")
